"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createOrUpdateConfig = exports.getConfig = void 0;
const logger_1 = require("./logger");
const fs_1 = require("fs");
const suf_log_1 = require("suf-log");
const suf_node_1 = require("suf-node");
const node_fetch_1 = __importDefault(require("node-fetch"));
const configPath = (extension) => `./suf.config.${extension}`;
function checkConfigExists() {
    return __awaiter(this, void 0, void 0, function* () {
        /*istanbul ignore else */
        if (yield suf_node_1.Exits(configPath('json')))
            return 'json';
        /*istanbul ignore else */
        if (yield suf_node_1.Exits(configPath('ts')))
            return 'ts';
        return null;
    });
}
function getConfig(Package) {
    return __awaiter(this, void 0, void 0, function* () {
        const extension = yield checkConfigExists();
        if (!extension) {
            logger_1.log('info', 'No config Found, do you want to create one? ', '[Y/n]');
            const answer = yield suf_node_1.getYNAnswer();
            if (answer) {
                const newConfig = yield createOrUpdateConfig(Package);
                if (!newConfig) {
                    process.exit(0);
                }
                return { config: newConfig, configPath: configPath('json') };
            }
            process.exit(1);
        }
        else {
            switch (extension) {
                case 'json':
                    return {
                        config: JSON.parse((yield fs_1.promises.readFile(configPath('json'))).toString()),
                        configPath: configPath('json'),
                    };
                case 'ts':
                    try {
                        const transpileModule = (yield Promise.resolve().then(() => __importStar(require('typescript')))).transpileModule;
                        const text = (yield fs_1.promises.readFile(configPath('ts'))).toString();
                        const config = eval(transpileModule(text, {}).outputText);
                        if (!config) {
                            logger_1.log('error', `${configPath('ts')} export is invalid.`);
                            process.exit(1);
                        }
                        return { config: config || {}, configPath: configPath('ts') };
                    }
                    catch (e) {
                        console.log(e);
                        logger_1.log('error', 'Please install typescript or use a .json config file!');
                        process.exit(1);
                    }
            }
        }
    });
}
exports.getConfig = getConfig;
function createOrUpdateConfig(packageJson, type, STATE) {
    return __awaiter(this, void 0, void 0, function* () {
        const path = (STATE === null || STATE === void 0 ? void 0 : STATE.configPath) || configPath('json');
        if (!path.endsWith('.json'))
            return undefined;
        let config;
        let updateOrCreate = 'Update';
        if (type && STATE) {
            logger_1.log('info', `Adding ${type} to Config.`);
            config = Object.assign(Object.assign({}, STATE.CONFIG), { [type]: yield configFuncs[type](packageJson) });
        }
        else {
            /**this will only be executed when there is no config. */
            config = {};
            updateOrCreate = 'Create';
            for (const key in configFuncs) {
                if (configFuncs.hasOwnProperty(key)) {
                    const configFunc = configFuncs[key];
                    logger_1.log('info', `Add ${key} to Config?`, '[Y/n]');
                    if (yield suf_node_1.getYNAnswer()) {
                        config = Object.assign(Object.assign({}, config), { [key]: yield configFunc(packageJson) });
                    }
                }
            }
        }
        console.log(`${suf_log_1.styler(`${updateOrCreate} Config`, logger_1.colors.blue)}: ${path}`);
        fs_1.promises.writeFile(path, JSON.stringify(config, null, 2));
        return config;
    });
}
exports.createOrUpdateConfig = createOrUpdateConfig;
const configFuncs = {
    badges: (Package) => __awaiter(void 0, void 0, void 0, function* () {
        return {
            name: yield getInp('Name', 'PACKAGE NAME', Package.name || ''),
            github: yield getInp('Github', 'Username'),
            repo: yield getInp('Github', 'Repo', Package.name || ''),
            out: yield getInp('out', 'OUTPUT PATH', 'README.md'),
            badges: [...(yield getBadges())],
        };
    }),
    tsDoc: () => __awaiter(void 0, void 0, void 0, function* () {
        return {
            title: yield getInp('title', 'TITLE', 'Docs'),
            dir: yield getInp('dir', 'INPUT PATH', 'dist'),
            out: yield getInp('out', 'OUTPUT PATH', 'README.md'),
        };
    }),
    license: () => __awaiter(void 0, void 0, void 0, function* () {
        return {
            name: yield getInp('name', 'FULL NAME(S)'),
            type: yield getLicenseType(),
            year: yield getInp('year', 'YEAR', new Date().getFullYear().toString()),
            out: yield getInp('out', 'OUTPUT PATH', 'README.md'),
            file: yield getInp('file', 'LICENSE FILE PATH', 'LICENSE'),
        };
    }),
};
function getLicenseType() {
    return __awaiter(this, void 0, void 0, function* () {
        process.stdout.write(suf_log_1.styler('Getting Licenses from api...\n', logger_1.colors.gray));
        const licenses = yield (yield node_fetch_1.default('https://api.github.com/licenses')).json();
        process.stdout.write(suf_log_1.styler('Choose From: ' +
            JSON.stringify(licenses.map((l) => l.key), null, 2).replace(/[\[\]",]/g, ''), logger_1.colors.gray));
        return yield getInp('type', 'LICENSE', 'mit');
    });
}
function getInp(type, type2, _default) {
    return __awaiter(this, void 0, void 0, function* () {
        process.stdout.write(suf_log_1.styler(type, logger_1.colors.blue));
        process.stdout.write(suf_log_1.styler(` ${type2}`, logger_1.colors.yellow));
        process.stdout.write(suf_log_1.styler(': ', logger_1.colors.gray));
        if (_default) {
            process.stdout.write(suf_log_1.styler(`(${_default})`, logger_1.colors.gray));
            const input = yield suf_node_1.readConsole();
            if (input.length === 0) {
                return _default;
            }
            return input;
        }
        return suf_node_1.readConsole();
    });
}
function getBadges(out) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!out) {
            out = [];
            process.stdout.write(suf_log_1.styler('Press Enter to Accept. ', logger_1.colors.info));
            process.stdout.write(suf_log_1.styler('Format: ', logger_1.colors.gray));
            process.stdout.write(suf_log_1.styler('BADGE ', logger_1.colors.blue));
            process.stdout.write(suf_log_1.styler('LINK ', logger_1.colors.yellow));
            process.stdout.write(suf_log_1.styler('Parameters?\n', logger_1.colors.gray));
        }
        process.stdout.write(suf_log_1.styler('Add', logger_1.colors.blue));
        process.stdout.write(suf_log_1.styler(' Badge', logger_1.colors.yellow));
        process.stdout.write(suf_log_1.styler(': ', logger_1.colors.gray));
        const input = yield suf_node_1.readConsole();
        if (/^e$|^end$|^$/i.test(input)) {
            if (input) {
                out.push(input);
            }
            return out;
        }
        else {
            if (input) {
                out.push(input);
            }
            return yield getBadges(out);
        }
    });
}
