"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.log = exports.genMessage = exports.colors = void 0;
const suf_log_1 = require("suf-log");
exports.colors = {
    info: '#f64',
    yellow: '#fc2',
    blue: '#08f',
    gray: '#aaa',
    error: '#f00',
};
exports.genMessage = (module) => `Generated ${module} at:`;
const loggers = {
    info: {
        styles: [exports.colors.info, exports.colors.yellow],
    },
    error: {
        styles: [{ color: exports.colors.error, 'font-weight': 'bold' }],
    },
    help: {
        styles: [
            { color: '#72a', background: '#111' },
            { color: '#f23', background: '#222' },
            { color: '#2af', background: '#222' },
        ],
    },
};
function log(type, ...messages) {
    if (type !== 'help') {
        suf_log_1.Log(...messages.map((msg, i) => suf_log_1.styler(msg, loggers[type].styles[i])));
    }
    else {
        console.log(nodeHelpMessage({
            text: `    INFO: All arguments can start with - or --, but i would recommend to just use letters.
    a | all: Calls all modules.
    b | badges: Calls the badges module.
    t | ts | d.ts | docs: Calls the tsDoc module.
    l | licence: Calls the license module.
    h | help: Displays this Message.`,
            splitter: ':',
            firstColumnWidth: 25,
            secondColumnWidth: 90,
        }, {
            styles: [
                { color: '#72a', background: '#111' },
                { color: '#f23', background: '#222' },
                { color: '#2af', background: '#222' },
            ],
            rawMessages: [],
        }));
    }
}
exports.log = log;
const nodeHelpMessage = (preset, data) => {
    if (preset.text) {
        const lines = preset.text.split(/\n/g);
        preset.text = undefined;
        let output = '';
        output += nodeHelpMessage(preset, Object.assign(Object.assign({}, data), { rawMessages: ['\n ', ' '] }));
        for (const line of lines) {
            output += nodeHelpMessage(preset, Object.assign(Object.assign({}, data), { rawMessages: '\n'.concat(line).split(preset.splitter) }));
        }
        output += nodeHelpMessage(preset, Object.assign(Object.assign({}, data), { rawMessages: ['\n ', ''] }));
        return output.replace(/^\n/, '');
    }
    else {
        const messages = [];
        for (let i = 0; i < data.rawMessages.length; i++) {
            messages.push({ message: data.rawMessages[i] });
        }
        const lastIndex = messages.length - 1;
        /*istanbul ignore else */
        if (messages.length > 1) {
            const space = preset.firstColumnWidth - messages[0].message.length;
            /*istanbul ignore else */
            if (space >= 0) {
                messages[0].message = messages[0].message
                    .replace(/^(\n)?/, '$1 ')
                    .concat(' '.repeat(space));
            }
            let concatenatedMessages = '';
            for (let i = 1; i < messages.length; i++) {
                concatenatedMessages += messages[i].message;
            }
            const endingSpace = preset.secondColumnWidth - (concatenatedMessages.length + (messages.length - 1) * 2);
            /*istanbul ignore else */
            if (endingSpace >= 0) {
                messages[lastIndex].message = messages[lastIndex].message.concat(' '.repeat(endingSpace));
            }
        }
        let output = '';
        for (let i = 0; i < messages.length; i++) {
            messages[i].message = messages[i].message.replace(/^(\n)?/, '$1 ');
            output += suf_log_1.styler(messages[i].message.concat('  '), data.styles[i]);
        }
        return output;
    }
};
