"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getArgs = exports.URI = exports.getPackageJson = exports.addArgToConfig = void 0;
const fs_1 = require("fs");
const suf_node_1 = require("suf-node");
const logger_1 = require("./logger");
function addArgToConfig(io) {
    if (io.args[io.i + 1]) {
        const nextArg = io.args[io.i + 1].replace(/["']?([^"']*)["']?/, '$1');
        if (io.exclude[io.name] !== undefined) {
            io.config[io.name] = nextArg;
        }
        else {
            io.config[io.name] = nextArg.split(',');
        }
    }
    else {
        logger_1.log('error', `--${io.name} ${io.args[io.i + 1]} not Found.`);
    }
}
exports.addArgToConfig = addArgToConfig;
function getPackageJson() {
    return __awaiter(this, void 0, void 0, function* () {
        const hasPackage = yield suf_node_1.Exits('./package.json');
        if (!hasPackage) {
            logger_1.log('info', 'No package.json found!');
            process.exit(1);
        }
        return JSON.parse((yield fs_1.promises.readFile('./package.json')).toString());
    });
}
exports.getPackageJson = getPackageJson;
class URI {
    constructor(path) {
        this.path = path;
        if (path.startsWith('http')) {
            this.type = 'url';
        }
        else {
            this.type = 'file';
        }
    }
}
exports.URI = URI;
function getArgs() {
    const [, , ...args] = process.argv;
    let ARGS = [];
    args.forEach((arg, i) => {
        ARGS[i] = arg.toLowerCase();
    });
    return ARGS;
}
exports.getArgs = getArgs;
